<?php

// provides statically used sanitizing functions
class MKS_Sanitizer
{
	// checks for true
	static function assertTrue($boolean, $description)
	{
		MKS_Sanitizer::assertNonEmptyStringSanitizedDescription($description, 'variable description for '.__METHOD__);
		
		if ($boolean !== true)
			throw new Exception('ERROR - not a boolean true: '.$description);
	}
	
	// checks for a number
	static function assertNumeric($number, $description)
	{
		MKS_Sanitizer::assertNonEmptyStringSanitizedDescription($description, 'variable description for '.__METHOD__);
		
		if (is_numeric($number) == false)
			throw new Exception('ERROR - not a number: '.$description);
	}
	
	// checks the integer and the description
	// allows 0, 1, 2, ...
	static function assertNonNegativeInteger($integer, $description)
	{
		MKS_Sanitizer::assertNonEmptyStringSanitizedDescription($description, 'variable description for '.__METHOD__);
		
		if (is_int($integer) == false)
			throw new Exception('ERROR - not an integer: '.$description);
		
		if ($integer < 0)
			throw new Exception('ERROR - negative integer: '.$description);
	}
	
	// checks only the string
	protected static function assertNonEmptyStringSanitizedDescription($string, $description_sanitized)
	{
		if (is_string($string) == false)
			throw new Exception('ERROR - not a string: '.$description_sanitized);
		
		if (strlen($string) < 1)
			throw new Exception('ERROR - empty string: '.$description_sanitized);
	}
	
	// checks the string and the description
	static function assertNonEmptyString($string, $description)
	{
		MKS_Sanitizer::assertNonEmptyStringSanitizedDescription($description, 'variable description for '.__METHOD__);
		MKS_Sanitizer::assertNonEmptyStringSanitizedDescription($string, $description);
	}
	
	// checks regular expression, match and description
	static function assertRegexMatch($pattern, $subject, $description)
	{
		MKS_Sanitizer::assertNonEmptyString($subject, $description);
		MKS_Sanitizer::assertNonEmptyStringSanitizedDescription($pattern, 'regex pattern for '.$description);
		
		$result = preg_match($pattern, $subject);
		
		if ($result === false)
			throw new Exception('ERROR - invalid regex pattern for: '.$description);
		
		if ($result != 1)
			throw new Exception('ERROR - cannot match to regex: '.$description);
	}
	
	// checks the array and the description
	static function assertNonEmptyArray($array, $description)
	{
		MKS_Sanitizer::assertNonEmptyStringSanitizedDescription($description, 'variable description for '.__METHOD__);
		
		if (is_array($array) == false)
			throw new Exception('ERROR - not an array: '.$description);
		
		if (count($array) < 1)
			throw new Exception('ERROR - empty array: '.$description);
	}
	
	// checks the file name, the description,
	// file existence and readability
	static function assertReadableFileName($string, $description)
	{
		MKS_Sanitizer::assertNonEmptyString($string, 'file name for '.$description);
		
		if (is_file($string) == false)
			throw new Exception('ERROR - file does not exist: '.$description);
		
		if (is_readable($string) == false)
			throw new Exception('ERROR - file cannot be read: '.$description);
	}
	
	// checks the number to be in the limits
	static function assertNumberBetween($min, $max, $number, $description)
	{
		MKS_Sanitizer::assertNonEmptyStringSanitizedDescription($description, 'variable description for '.__METHOD__);
		MKS_Sanitizer::assertNumeric($min, 'lower limit for '.$description);
		MKS_Sanitizer::assertNumeric($max, 'upper limit for '.$description);
		MKS_Sanitizer::assertNumeric($number, $description);
		
		if ($number < $min)
			throw new Exception('ERROR - below limit: '.$description);
		
		if ($number > $max)
			throw new Exception('ERROR - above limit: '.$description);
	}
	
	// checks the file handle and the description
	static function assertOpenFileHandle($handle, $description)
	{
		MKS_Sanitizer::assertNonEmptyStringSanitizedDescription($description, 'variable description for '.__METHOD__);
				
		if (is_resource($handle) == false)
			throw new Exception('ERROR - not a file handle: '.$description);
		
		if (get_resource_type($handle) != 'stream')
			throw new Exception('ERROR - not a file handle: '.$description);
	}
}

?>