<?php

// configuration section
$testCases = array(
	'029279' => 'D013 Ins. Rev. 3.0',
	'030281' => 'D13X Rev. 3.0',
	'031633' => 'D743 Rev. 6.0',
	'031965' => 'D747 Rev. 2.2',
	'032142' => 'D113 Rev. 7.0');
$includePath = 'inc/';
$temporaryPath = 'tmp/';
$archivePath = '//duagon.ads/dfs/d_Archive/';
$newLine = "<br>\r\n";
$layers = array('GM1', 'GM2', 'GM3');

// create temporary folder
if (!is_dir($temporaryPath))
	mkdir($temporaryPath);

// load all classes
if (($files = @scandir($includePath)) === false)
    die('Could not open include path: '.$includePath);

foreach ($files as $file)
    if (substr($file, 0, 1) != '.')
        include($includePath.$file);

// run all test cases
foreach ($testCases as $docNumber => $description)
{
	try
	{
		echo '<h2>'.$description.'</h2>';
		$gerberPath = $archivePath.'d-'.$docNumber.'/Gerber*';
		
		// ------------------------ //
		// locate the outline files //
		// ------------------------ //
		
		$FF = new MKS_FileFinder();
		$FF->setSingle(true);
		$fileName = array();
		
		try
		{
			// try to find the files in a folder
			foreach ($layers as $layer)
			{
				$FF->setPattern($gerberPath.'/*.'.$layer);
				$fileName[$layer] = $FF->getResult();
			}
		}
		catch (Exception $e)
		{
			// incomplete set given
			if ($layer != $layers[0])
				throw $e;
			
			// try to find the files in a ZIP file
			$FF->setPattern($gerberPath.'.zip');
			$fileNameZIP = $FF->getResult();
			
			// extract the entire ZIP file to a temporary folder
			$GZ = new ZipArchive();
			$success = $GZ->open($fileNameZIP);
			MKS_Sanitizer::assertTrue($success, 'ZIP open return value');
			$success = $GZ->extractTo($temporaryPath.'d-'.$docNumber.'/');
			MKS_Sanitizer::assertTrue($success, 'ZIP extractTo return value');
			$GZ->close();
			
			// set a new source for the gerber files
			$gerberPath = $temporaryPath.'d-'.$docNumber;
			
			// try to find the files in the temp folder
			foreach ($layers as $layer)
			{
				$FF->setPattern($gerberPath.'/*.'.$layer);
				$fileName[$layer] = $FF->getResult();
			}
		}
		
		unset($FF);
		
		$GI = new MKS_GerberInterpreter();
		$GI->setDescription($description);
		$GI->parseOutline($fileName['GM1']);
		$GI->parseOutlineSingle($fileName['GM2']);
		$GM1Sets = $GI->getPanelStructuresCount();
		$GM2Sets = $GI->getSingleStructuresCount();
		$panel = $GI->getPanelDimensions();
		$border = $GI->getPanelBorder();
		$single = $GI->getSingleSize();
		
		echo 'panel ('.$GM1Sets.' structures)'.$newLine
			.'X: <b>'.($panel[1]-$panel[0]).'</b>mm'.$newLine
			.'Y: <b>'.($panel[3]-$panel[2]).'</b>mm'.$newLine
			.$newLine
			.'<img src="'.$description.' GM1.png">'.$newLine
			.$newLine
			.'panel border'.$newLine
			.'X: <b>'.($border[0]).'mm</b>,  '.($border[1]).'mm'.$newLine
			.'Y: <b>'.($border[2]).'mm</b>,  '.($border[3]).'mm'.$newLine
			.$newLine
			.'<img src="'.$description.' GM2.png">'.$newLine
			.$newLine
			.'single ('.$GM2Sets.' structures, unknown number of PCBs)'.$newLine
			.'X: <b>'.$single[0].'mm</b>'.$newLine
			.'Y: <b>'.$single[1].'mm</b>'.$newLine
			.$newLine;
	}
	catch (Exception $e)
	{
		echo $e->getMessage().$newLine
			.$newLine;
	}
}

// rm -r in PHP
function rrmdir($src)
{
	$dir = opendir($src);
	while(false !== ( $file = readdir($dir)) )
	{
		if (( $file != '.' ) && ( $file != '..' )) {
			$full = $src . '/' . $file;
			if ( is_dir($full) ) {
				rrmdir($full);
			}
			else {
				unlink($full);
			}
		}
	}
	closedir($dir);
	rmdir($src);
}

// remove temporary folder
rrmdir($temporaryPath);

?>